@@ -40,13 +40,13 @@ class Graph : public QWidget
   void setColorA(const QColor &);
   void setColorB(const QColor &);
   void setColorBg(const QColor &);
-  QColor getColorA() const { return colorA; };
-  QColor getColorB() const { return colorB; };
-  QColor getColorBg() const { return colorBg; };
+  QColor getColorA() const { return colorA; }
+  QColor getColorB() const { return colorB; }
+  QColor getColorBg() const { return colorBg; }
   void setMaxValue(unsigned int m);
   void unsetMaxValue();
-  unsigned int getMaxValue() { return maxValue; };
-  bool autoMax() { return autoMaxValue; };
+  unsigned int getMaxValue() { return maxValue; }
+  bool autoMax() { return autoMaxValue; }
 
  protected:
   virtual void resizeEvent(QResizeEvent *);
