@@ -37,6 +37,7 @@
 #include <kaboutapplication.h>
 #include <kpopupmenu.h>
 #include <kprocess.h>
+#include <kglobalaccel.h>
 
 #include "statusbutton.h"
 #include "light.h"
@@ -123,8 +124,15 @@ KModemLightsApplet::KModemLightsApplet(const QString& configFile, Type type,
   popup->insertItem(SmallIcon("configure"), i18n("&Settings..."), this,
 		    SLOT(preferences()));
 
+  accel = new KGlobalAccel(this);
+  accel->setConfigGroup("Shortcuts");
+  accel->insert("onoffline", i18n("Go on/offline"),
+		i18n("Go on/offline with the kmodemlights applet"),
+		0, 0, // ALT+Key_I, WIN+Key_I,
+		this, SLOT(dial()));
+
   readConfig();
-  
+
   timerID = startTimer(1000/updateFrequency);
 }
 
@@ -132,6 +140,8 @@ KModemLightsApplet::~KModemLightsApplet()
 {
   killTimer(timerID);
   if(aboutData) delete aboutData;
+
+  delete accel;
 }
 
 QFont KModemLightsApplet::fontForHeight(int widgetheight) const
@@ -465,6 +475,11 @@ void KModemLightsApplet::preferences()
     config()->writeEntry("Graph background", dlg.graphBgColor());
     config()->writeEntry("Await color", dlg.statusAwaitColor());
     config()->writeEntry("On color", dlg.statusOnColor());
+
+    // Shortcuts
+    dlg.commitShortcuts();
+    accel->writeSettings(config());
+
     config()->sync();
 
     readConfig();
@@ -520,5 +535,8 @@ void KModemLightsApplet::readConfig()
   button->setColor(StatusButton::On,
 		   config()->readColorEntry("On color", &CGreen));
 
+  accel->readSettings(config());
+  accel->updateConnections();
+
   updateLayout();
 }
