@@ -27,6 +27,7 @@
 
 #include <kdialogbase.h>
 #include <kcolorbutton.h>
+#include <kkeydialog.h>
 
 #include "statusbutton.h"
 
@@ -37,8 +38,8 @@ class KModemLightsDlg : public KDialogBase {
 
  public:
 
-  KModemLightsDlg::KModemLightsDlg(KModemLightsApplet *ap, QWidget *parent = 0, 
-				   const char *name = 0);
+  KModemLightsDlg(KModemLightsApplet *ap, QWidget *parent = 0, 
+		  const char *name = 0);
 
   // get Device
   QString deviceName() const { return deviceWidget->text(); }
@@ -67,12 +68,16 @@ class KModemLightsDlg : public KDialogBase {
   QColor statusOnColor() const { return statusOn->color(); }
   QColor graphBgColor() const { return graphBg->color(); }
 
+  // Commit Shortcuts
+  void commitShortcuts() const { shortcutWidget->commitChanges(); }
+
  private:
 
   QWidget *generateGeneral();
   QWidget *generateAppearance();
   QWidget *generateDevice();
   QWidget *generateColor();
+  QWidget *generateShortcut();
   QLabel *newCaption(const QString &s, QWidget *w);
 
   KModemLightsApplet *applet;
@@ -97,6 +102,9 @@ class KModemLightsDlg : public KDialogBase {
   KColorButton *statusAwait, *statusOn;
   KColorButton *graphBg;
 
+  // Shortcuts
+  KKeyChooser *shortcutWidget;
+
  private slots:
 
   void help();
