@@ -34,9 +34,9 @@ class Modem
   int getConnectTime(bool recalc);
   
   void setDeviceName(const char *deviceName);
-  const char *deviceName() const { return DeviceName; };
+  const char *deviceName() const { return DeviceName; }
   void setLockFile(const char *lockFile);
-  const char *lockFile() const { return LockFile; };
+  const char *lockFile() const { return LockFile; }
 
  private:
 
