@@ -31,24 +31,31 @@ class StatusButton : public QPushButton
 
  public:
 
+  enum IconSize { smallIcon=0, mediumIcon, largeIcon };	// these are indexes!
+  enum Status { On, Off, Wait };
+
   StatusButton(QWidget *parent, const char *name = 0);
  
-  enum Status { On, Off, Wait };
   void setStatus(const Status s);
-  Status status() const { return myStatus; };
+  Status status() const { return myStatus; }
 
   void setColor(const Status s, const QColor &c);
-  QColor getColor(const Status s) const;
+  QColor color(const Status s) const;
 
+  void setIconSize(IconSize size);
+  IconSize iconSize() const { return myIconSize; }
+  
  public slots:
 
  private:
 
   void generateIcon(QPixmap &px, const QPixmap &sign, const QColor &col);
+  void setIcon(Status s);
 
   QPixmap on, off, wait;
-  QPixmap signOn, signOff, signWait, signMask;
+  QPixmap signOn[3], signOff[3], signWait[3], signMask[3];
   QColor colorOn, colorWait;
+  IconSize myIconSize;
 
   enum Status myStatus;
 };
